{% extends "_base.html" %}

{% block body %}

<div class="container">

    <div class="row">

        <div class="col-md-8 role="main">
            {% for item in this.content %}
                <div> 
                  <h3>{{item.date|dateformat}}&nbsp;&nbsp;{{item.title}}</h3>
                </div>
                <div>
                    {{item.body}}
                    <hr>
                </div>
            {% endfor %}
        </div>

    </div>

    {% include 'footer.html' %}

</div 

{% endblock %}

